==========
Background
==========

This tutorial presents a :app:`Pyramid` application that uses technologies
which will be familiar to someone with SQL database experience.  It uses
:term:`SQLAlchemy` as a persistence mechanism and :term:`url dispatch` to map
URLs to code.

To code along with this tutorial, the developer will need a UNIX
machine with development tools (Mac OS X with XCode, any Linux or BSD
variant, etc) *or* a Windows system of any kind.

.. warning::

  This tutorial has been written for Python 2.  It is unlikely to work
  without modification under Python 3.

Have fun!
